@@ -18,7 +18,7 @@ from ddeutil.core import (
     isinstance_check,
     must_split,
 )
-from ddeutil.core.dtutils import next_date, replace_date
+from ddeutil.core.dtutils import DatetimeMode, next_date, replace_date
 
 WEEKDAYS: dict[str, int] = {
     "Sun": 0,
@@ -31,13 +31,14 @@ WEEKDAYS: dict[str, int] = {
 }
 
 
-class CronYearLimit(Exception): ...
+class YearReachLimit(Exception):
+    """"""
 
 
 def str2cron(value: str) -> str:  # pragma: no cov
     """Convert Special String with the @ prefix to Crontab value.
 
-    :param value: A string value that want to convert to cron value.
+    :param value: (str) A string value that want to convert to cron value.
     :rtype: str
 
     Table:
@@ -82,6 +83,9 @@ class Unit:
         )
 
 
+Units = tuple[Unit, ...]
+
+
 @dataclass
 class Options:
     """Options dataclass for config CronPart object."""
@@ -91,7 +95,7 @@ class Options:
     output_hashes: bool = False
 
 
-CRON_UNITS: tuple[Unit, ...] = (
+CRON_UNITS: Units = (
     Unit(
         name="minute",
         range=partial(range, 0, 60),
@@ -147,7 +151,7 @@ CRON_UNITS: tuple[Unit, ...] = (
     ),
 )
 
-CRON_UNITS_YEAR: tuple[Unit, ...] = CRON_UNITS + (
+CRON_UNITS_YEAR: Units = CRON_UNITS + (
     Unit(
         name="year",
         range=partial(range, 1990, 2101),
@@ -175,7 +179,7 @@ class CronPart:
     def __init__(
         self,
         unit: Unit,
-        values: str | list[int],
+        values: Union[str, list[int]],
         options: Options,
     ) -> None:
         self.unit: Unit = unit
@@ -220,55 +224,71 @@ class CronPart:
         return ",".join(cron_range_strings) if cron_range_strings else "?"
 
     def __repr__(self) -> str:
+        """Override __repr__ method."""
         return (
             f"{self.__class__.__name__}"
             f"(unit={self.unit}, values={self.__str__()!r})"
         )
 
-    def __lt__(self, other) -> bool:
+    def __lt__(self, other: Union[CronPart, list]) -> bool:
+        """Override __lt__ method."""
         if isinstance(other, CronPart):
             return self.values < other.values
         elif isinstance(other, list):
             return self.values < other
+        return NotImplemented
 
-    def __eq__(self, other) -> bool:
+    def __eq__(self, other: Union[CronPart, list]) -> bool:
+        """Override __eq__ method."""
         if isinstance(other, CronPart):
             return self.values == other.values
         elif isinstance(other, list):
             return self.values == other
+        return NotImplemented
 
     @property
     def min(self) -> int:
-        """Returns the smallest value in the range."""
+        """Returns the smallest value in the range.
+
+        :rtype: int
+        """
         return self.values[0]
 
     @property
     def max(self) -> int:
-        """Returns the largest value in the range."""
+        """Returns the largest value in the range.
+
+        :rtype: int
+        """
         return self.values[-1]
 
     @property
     def step(self) -> Optional[int]:
         """Returns the difference between first and second elements in the
         range.
+
+        :rtype: Optional[int]
         """
         if (
             len(self.values) > 2
             and (step := self.values[1] - self.values[0]) > 1
         ):
             return step
+        return None
 
     @property
     def is_full(self) -> bool:
-        """Returns true if range has all the values of the unit."""
+        """Returns true if range has all the values of the unit.
+
+        :rtype: bool
+        """
         return len(self.values) == (self.unit.max - self.unit.min + 1)
 
     def from_str(self, value: str) -> tuple[int, ...]:
         """Parses a string as a range of positive integers. The string should
         include only `-` and `,` special strings.
 
-        :param value: A string value that want to parse
-        :type value: str
+        :param value: (str) A string value that want to parse
 
         TODO: support for `L`, `W`, and `#`
         ---
@@ -339,6 +359,8 @@ class CronPart:
                     f"Invalid interval step value {value_step!r} for "
                     f"{self.unit.name!r}"
                 )
+            elif value_step:
+                value_step: int = int(value_step)
 
             # NOTE: Generate interval that has step
             interval_list.append(self._interval(value_range_list, value_step))
@@ -351,16 +373,21 @@ class CronPart:
             For example if value == 'JAN,AUG' it will replace to '1,8'.
 
         :param value: A string value that want to replace alternative to int.
+
+        :rtype: str
         """
         for i, alt in enumerate(self.unit.alt):
             if alt in value:
                 value: str = value.replace(alt, str(self.unit.min + i))
         return value
 
-    def replace_weekday(self, values: list[int] | Iterator[int]) -> list[int]:
+    def replace_weekday(
+        self, values: Union[list[int], Iterator[int]]
+    ) -> list[int]:
         """Replaces all 7 with 0 as Sunday can be represented by both.
 
         :param values: list or iter of int that want to mode by 7
+
         :rtype: list[int]
         """
         if self.unit.name == "weekday":
@@ -388,7 +415,13 @@ class CronPart:
         return values
 
     def _parse_range(self, value: str) -> list[int]:
-        """Parses a range string."""
+        """Parses a range string from a cron-part.
+
+        :param value: (str) A cron-part string value that want to parse.
+
+        :rtype: list[int]
+        :return: A list of parse range.
+        """
         if value == "*":
             return list(self.unit.range())
         elif value.count("-") > 1:
@@ -408,9 +441,15 @@ class CronPart:
     def _interval(
         self,
         values: list[int],
-        step: int | None = None,
+        step: Optional[int] = None,
     ) -> list[int]:
-        """Applies an interval step to a collection of values."""
+        """Applies an interval step to a collection of values.
+
+        :param values:
+        :param step: (int) A step
+
+        :rtype: list[int]
+        """
         if not step:
             return values
         elif (_step := int(step)) < 1:
@@ -427,7 +466,10 @@ class CronPart:
 
     @property
     def is_interval(self) -> bool:
-        """Returns true if the range can be represented as an interval."""
+        """Returns true if the range can be represented as an interval.
+
+        :rtype: bool
+        """
         if not (step := self.step):
             return False
         for idx, value in enumerate(self.values):
@@ -439,7 +481,10 @@ class CronPart:
 
     @property
     def is_full_interval(self) -> bool:
-        """Returns true if the range contains all the interval values."""
+        """Returns true if the range contains all the interval values.
+
+        :rtype: bool
+        """
         if step := self.step:
             return (
                 self.min == self.unit.min
@@ -465,10 +510,10 @@ class CronPart:
             except IndexError:
                 next_value: int = -1
             if value != (next_value - 1):
-                # NOTE: ``next_value`` is not the subsequent number
+                # NOTE: `next_value` is not the subsequent number
                 if start_number is None:
                     # NOTE:
-                    #   The last number of the list ``self.values`` is not in a
+                    #   The last number of the list `self.values` is not in a
                     #   range.
                     multi_dim_values.append(value)
                 else:
@@ -478,12 +523,11 @@ class CronPart:
                 start_number: Optional[int] = value
         return multi_dim_values
 
-    def filler(self, value: int) -> int | str:
+    def filler(self, value: int) -> Union[int, str]:
         """Formats weekday and month names as string when the relevant options
         are set.
 
-        :param value: a int value
-        :type value: int
+        :param value: (int) An int value that want to get from the unit.
 
         :rtype: int | str
         """
@@ -538,8 +582,8 @@ class CronJob:
             monitor-data-warehouse-schedule.html
     """
 
-    cron_length: int = 5
-    cron_units: tuple[Unit, ...] = CRON_UNITS
+    cron_length: ClassVar[int] = 5
+    cron_units: ClassVar[Units] = CRON_UNITS
 
     def __init__(
         self,
@@ -600,52 +644,81 @@ class CronJob:
 
     @property
     def parts_order(self) -> Iterator[CronPart]:
+        """Return iterator of CronPart instance.
+
+        :rtype: Iterator[CronPart]
+        """
         return reversed(self.parts[:3] + [self.parts[4], self.parts[3]])
 
     @property
     def minute(self) -> CronPart:
-        """Return part of minute."""
+        """Return part of minute with the CronPart instance.
+
+        :rtype: CronPart
+        """
         return self.parts[0]
 
     @property
     def hour(self) -> CronPart:
-        """Return part of hour."""
+        """Return part of hour with the CronPart instance.
+
+        :rtype: CronPart
+        """
         return self.parts[1]
 
     @property
     def day(self) -> CronPart:
-        """Return part of day."""
+        """Return part of day with the CronPart instance.
+
+        :rtype: CronPart
+        """
         return self.parts[2]
 
     @property
     def month(self) -> CronPart:
-        """Return part of month."""
+        """Return part of month with the CronPart instance.
+
+        :rtype: CronPart
+        """
         return self.parts[3]
 
     @property
     def dow(self) -> CronPart:
-        """Return part of day of month."""
+        """Return part of day of month with the CronPart instance.
+
+        :rtype: CronPart
+        """
         return self.parts[4]
 
     def to_list(self) -> list[list[int]]:
-        """Returns the cron schedule as a 2-dimensional list of integers."""
+        """Returns the cron schedule as a 2-dimensional list of integers.
+
+        :rtype: list[list[int]]
+        """
         return [part.values for part in self.parts]
 
     def check(self, date: datetime, mode: str) -> bool:
+        """Check the date value with the mode.
+
+        :rtype: bool
+        """
         assert mode in ("year", "month", "day", "hour", "minute")
         return getattr(date, mode) in getattr(self, mode).values
 
     def schedule(
         self,
-        date: datetime | None = None,
+        date: Optional[datetime] = None,
         *,
-        tz: str | None = None,
+        tz: Optional[str] = None,
     ) -> CronRunner:
-        """Returns the schedule datetime runner with this cronjob. It would run
-        ``next``, ``prev``, or ``reset`` to generate running date that you want.
+        """Returns CronRunner instance that be datetime runner with this
+        cronjob. It can use `next`, `prev`, or `reset` methods to generate
+        running date.
 
-        :param date: An initial date that want to mark as the start point.
-        :param tz: A string timezone that want to change on runner.
+        :param date: (datetime) An initial date that want to mark as the start
+            point. (Default is use the current datetime)
+        :param tz: (str) A string timezone that want to change on runner.
+            (Default is None)
 
         :rtype: CronRunner
         """
@@ -667,18 +740,24 @@ class CronJobYear(CronJob):
         (vi)    year (1990 - 2100)
     """
 
-    cron_length = 6
-    cron_units = CRON_UNITS_YEAR
+    cron_length: ClassVar[int] = 6
+    cron_units: ClassVar[Units] = CRON_UNITS_YEAR
 
     @property
     def year(self) -> CronPart:
-        """Return part of year."""
+        """Return part of year with the CronPart instance.
+
+        :rtype: CronPart"""
         return self.parts[5]
 
 
 class CronRunner:
     """Create an instance of Date Runner object for datetime generate with
     cron schedule object value.
+
+    :param cron: (CronJob | CronJobYear)
+    :param date: (datetime)
+    :param tz: (str)
     """
 
     shift_limit: ClassVar[int] = 25
@@ -694,14 +773,20 @@ class CronRunner:
 
     def __init__(
         self,
-        cron: CronJob | CronJobYear,
-        date: datetime | None = None,
+        cron: Union[CronJob, CronJobYear],
+        date: Optional[datetime] = None,
         *,
-        tz: str | None = None,
+        tz: Optional[Union[str, ZoneInfo]] = None,
     ) -> None:
-        # NOTE: Prepare timezone if this value does not set, it will use UTC.
-        self.tz: ZoneInfo = ZoneInfo("UTC")
+        self.tz: Optional[ZoneInfo] = None
         if tz:
+            if isinstance(tz, ZoneInfo):
+                self.tz = tz
+            elif not isinstance(tz, str):
+                raise TypeError(
+                    "Invalid type of `tz` parameter, it should be str or "
+                    "ZoneInfo instance."
+                )
             try:
                 self.tz = ZoneInfo(tz)
             except ZoneInfoNotFoundError as err:
@@ -713,9 +798,10 @@ class CronRunner:
                 raise ValueError(
                     "Input schedule start time is not a valid datetime object."
                 )
-            if tz is None:
-                self.tz = date.tzinfo
-            self.date: datetime = date.astimezone(self.tz)
+            if tz is not None:
+                self.date: datetime = date.astimezone(self.tz)
+            else:
+                self.date: datetime = date
         else:
             self.date: datetime = datetime.now(tz=self.tz)
 
@@ -732,7 +818,7 @@ class CronRunner:
             )
 
         self.__start_date: datetime = self.date
-        self.cron: CronJob | CronJobYear = cron
+        self.cron: Union[CronJob, CronJobYear] = cron
         self.is_year: bool = isinstance(cron, CronJobYear)
         self.reset_flag: bool = True
 
@@ -785,7 +871,7 @@ class CronRunner:
 
         raise RecursionError("Unable to find execution time for schedule")
 
-    def __shift_date(self, mode: str, reverse: bool = False) -> bool:
+    def __shift_date(self, mode: DatetimeMode, reverse: bool = False) -> bool:
         """Increments the mode of date value ("month", "day", "hour", "minute")
         until matches with the schedule.
 
@@ -819,8 +905,8 @@ class CronRunner:
                 getattr(self.date, mode)
                 > (max_year := max(self.cron.year.values))
             ):
-                raise CronYearLimit(
-                    f"The year is out of limit with this crontab value: "
+                raise YearReachLimit(
+                    f"The year is reach the limit with this crontab setting: "
                     f"{max_year}."
                 )
 
@@ -839,11 +925,3 @@ class CronRunner:
 
         # NOTE: Return False if the date that match with condition.
         return False
-
-
-__all__ = (
-    "CronJob",
-    "CronJobYear",
-    "CronRunner",
-    "WEEKDAYS",
-)
